# Security Policy

## Supported Versions
<!--
Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 5.1.x   | :white_check_mark: |
| 5.0.x   | :x:                |
| 4.0.x   | :white_check_mark: |
| < 4.0   | :x:                |
-->

Each major version is currently being supported with security updates.

| Version | Supported          |
|---------|--------------------|
| 1.x.x   | :white_check_mark: |
| 2.x.x   | :white_check_mark: |


## Reporting a Vulnerability
<!--
Use this section to tell people how to report a vulnerability.

Tell them where to go, how often they can expect to get an update on a
reported vulnerability, what to expect if the vulnerability is accepted or
declined, etc.
-->

To report a security vulnerability, please contact: security@huggingface.co
